@@ -121,8 +121,8 @@ def get_collection_number(
     if producer == "usgs.gov":
         return usgs_collection_number
     elif producer == "ga.gov.au":
-        # GA's collection 3 processes USGS Collection 1
-        if usgs_collection_number == 1:
+        # GA's collection 3 processes USGS Collection 1 and 2
+        if usgs_collection_number == 1 or usgs_collection_number == 2:
             return 3
         else:
             raise NotImplementedError("Unsupported GA collection number.")
