@@ -1,7 +1,7 @@
 """
 Package WAGL HDF5 Outputs
 
-This will convert the HDF5 file (and sibling fmask/gqa files) into
+This converts the HDF5 file (and sibling fmask/gqa files) into
 GeoTIFFS (COGs) with datacube metadata using the DEA naming conventions
 for files.
 """
@@ -232,7 +232,7 @@ def _unpack_observation_attributes(
 def choose_resolution_group(
     resolution_groups: Dict[tuple, h5py.Group],
     platform: str,
-    oa_resolution=Optional[Tuple[float, float]],
+    oa_resolution: Optional[Tuple[float, float]],
 ) -> h5py.Group:
 
     # None specified? Figure out a default.
@@ -243,7 +243,7 @@ def choose_resolution_group(
         if platform.startswith("landsat"):
             oa_resolution = max(resolution_groups.keys())
         elif platform.startswith("sentinel"):
-            oa_resolution = (20.0, 20.0)
+            oa_resolution = (10.0, 10.0)
         else:
             raise NotImplementedError(
                 f"Don't know how to choose a default OA resolution for platform {platform !r}"
@@ -350,6 +350,22 @@ def do(name: str, heading=False, **fields):
         secho("(done)")
 
 
+def _get_level1_metadata_path(wagl_doc: Dict) -> Optional[Path]:
+    """
+    Find the expected matching metadata file for the source dataset
+    """
+    source_level1 = Path(get_path(wagl_doc, ("source_datasets", "source_level1")))
+    if not source_level1.exists():
+        return None
+
+    # If a directory, assume "<dirname>.odc-metadata.yaml"
+    if source_level1.is_dir():
+        return source_level1 / (source_level1.name + ".odc-metadata.yaml")
+    # Otherwise it's a sibling file with ".odc-metadata.yaml" suffix
+    else:
+        return source_level1.with_suffix(".odc-metadata.yaml")
+
+
 def _extract_reference_code(p: DatasetAssembler, granule: str) -> Optional[str]:
     matches = None
     if p.platform.startswith("landsat"):
@@ -421,13 +437,7 @@ class Granule:
                 [wagl_doc] = loads_yaml(wagl_doc_field[()])
 
                 if not level1_metadata_path:
-                    level1_tar_path = Path(
-                        get_path(wagl_doc, ("source_datasets", "source_level1"))
-                    )
-                    if level1_tar_path.exists():
-                        level1_metadata_path = level1_tar_path.with_suffix(
-                            ".odc-metadata.yaml"
-                        )
+                    level1_metadata_path = _get_level1_metadata_path(wagl_doc)
                 if level1_metadata_path and not level1_metadata_path.exists():
                     raise ValueError(
                         f"No level1 metadata found at {level1_metadata_path}"
@@ -516,7 +526,7 @@ def package(
     granule: Granule,
     included_products: Iterable[str] = DEFAULT_PRODUCTS,
     include_oa: bool = True,
-    oa_resolution=Optional[Tuple[float, float]],
+    oa_resolution: Optional[Tuple[float, float]] = None,
 ) -> Tuple[UUID, Path]:
     """
     Package an L2 product.
@@ -542,14 +552,17 @@ def package(
     with h5py.File(granule.wagl_hdf5, "r") as fid:
         granule_group = fid[granule.name]
 
+        wagl_doc = _read_wagl_metadata(granule_group)
+
         with DatasetAssembler(
             out_directory.absolute(),
             # WAGL stamps a good, random ID already.
             dataset_id=granule.wagl_metadata.get("id"),
-            # naming_conventions="dea_s2" if ('sentinel' in p.platform) else "dea",
-            naming_conventions="dea",
+            naming_conventions="dea_s2"
+            if ("sentinel" in wagl_doc["source_datasets"]["platform_id"].lower())
+            else "dea",
         ) as p:
-            wagl_doc = _apply_wagl_metadata(p, granule_group)
+            _apply_wagl_metadata(p, wagl_doc)
 
             # It's a GA ARD product.
             p.producer = "ga.gov.au"
@@ -583,7 +596,7 @@ def package(
                 p.platform, p.producer, p.properties.get("landsat:collection_number")
             )
 
-            p.dataset_version = f"{org_collection_number}.2.0"
+            p.dataset_version = f"{org_collection_number}.2.1"
             p.region_code = _extract_reference_code(p, granule.name)
 
             _read_gqa_doc(p, granule.gqa_doc)
@@ -681,7 +694,7 @@ def find_a_granule_name(wagl_hdf5: Path) -> str:
     return wagl_hdf5.name[: -len(".wagl.h5")]
 
 
-def _apply_wagl_metadata(p: DatasetAssembler, granule_group: h5py.Group) -> Dict:
+def _read_wagl_metadata(granule_group: h5py.Group):
     try:
         wagl_path, *ancil_paths = [
             pth
@@ -693,6 +706,14 @@ def _apply_wagl_metadata(p: DatasetAssembler, granule_group: h5py.Group) -> Dict
 
     [wagl_doc] = loads_yaml(granule_group[wagl_path][()])
 
+    for i, path in enumerate(ancil_paths, start=2):
+        wagl_doc.setdefault(f"wagl_{i}", {}).update(
+            list(loads_yaml(granule_group[path][()]))[0]["ancillary"]
+        )
+    return wagl_doc
+
+
+def _apply_wagl_metadata(p: DatasetAssembler, wagl_doc: Dict):
     source = wagl_doc["source_datasets"]
     p.datetime = source["acquisition_datetime"]
     p.platform = source["platform_id"]
@@ -701,16 +722,10 @@ def _apply_wagl_metadata(p: DatasetAssembler, granule_group: h5py.Group) -> Dict
     try:
         p.processed = get_path(wagl_doc, ("system_information", "time_processed"))
     except PathAccessError:
-        raise ValueError(f"WAGL dataset contains no time processed. Path {wagl_path}")
-
-    for i, path in enumerate(ancil_paths, start=2):
-        wagl_doc.setdefault(f"wagl_{i}", {}).update(
-            list(loads_yaml(granule_group[path][()]))[0]["ancillary"]
-        )
+        raise RuntimeError("WAGL dataset contains no processed time.")
 
     _take_software_versions(p, wagl_doc)
     p.extend_user_metadata("wagl", wagl_doc)
-    return wagl_doc
 
 
 def _determine_maturity(acq_date: datetime, processed: datetime, wagl_doc: Dict):
